#
# spec file for package rabbitmq-server
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _rabbit_erllibdir %{_libdir}/rabbitmq/lib/rabbitmq_server-%{version}
%define _rabbit_libdir %{_libdir}/rabbitmq

%if %{undefined _initddir}
%define _initddir %{_sysconfdir}/init.d
%endif

Name:           rabbitmq-server
Version:        3.5.8
Release:        6.18
Summary:        The RabbitMQ Server
License:        MPL-1.1
Group:          System/Daemons
Url:            http://www.rabbitmq.com/
Source:         http://www.rabbitmq.com/releases/rabbitmq-server/v%{version}/%{name}-%{version}.tar.gz
Source1:        rabbitmq-server.init
# This comes from: http://hg.rabbitmq.com/rabbitmq-server/raw-file/2da625c0a436/packaging/common/rabbitmq-script-wrapper
Source2:        rabbitmq-script-wrapper
Source3:        rabbitmq-server.logrotate
Source4:        rabbitmq-server.ocf
Source5:        rabbitmq-server.sysconfig
Source6:        rabbitmq-server.service
Source7:        rabbitmq-server.tmpfiles.d.conf
Patch0:         no-nmap.patch
Patch1:         no-remove-common.patch
BuildRequires:  erlang
BuildRequires:  erlang-src
BuildRequires:  fdupes
BuildRequires:  libxslt
# require python json module
BuildRequires:  python >= 2.6
BuildRequires:  python-xml
BuildRequires:  unzip
BuildRequires:  xmlto
BuildRequires:  zip
Requires:       erlang
Requires:       logrotate
Provides:       AMQP-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  pwdutils
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
%if 0%{?suse_version} > 1140
BuildRequires:  systemd
%{?systemd_requires}
%define have_systemd 1
Requires:       erlang-sd_notify
%else
Requires:       %fillup_prereq
Requires:       %insserv_prereq
%endif
# Do not use noarch since the Erlang packaging does not really allow that
#BuildArch:      noarch

%description
RabbitMQ is an implementation of AMQP, the emerging standard for high
performance enterprise messaging. The RabbitMQ server is a robust and
scalable implementation of an AMQP broker.

%package plugins
Summary:        Plugins for the RabbitMQ server
Group:          System/Daemons
Requires:       rabbitmq-server = %{version}

%description plugins
RabbitMQ is an implementation of AMQP, the emerging standard for high
performance enterprise messaging. The RabbitMQ server is a robust and
scalable implementation of an AMQP broker.

This package includes some plugins for the RabbitMQ server

%package -n erlang-rabbitmq-client
Summary:        RabbitMQ AMQP language bindings for Erlang
Group:          Development/Libraries/Other
Requires:       erlang
Provides:       erlang-gen_server2 = %{version}

%description -n erlang-rabbitmq-client
RabbitMQ is an implementation of AMQP, the emerging standard for high
performance enterprise messaging. The RabbitMQ server is a robust and
scalable implementation of an AMQP broker.

This package includes the RabbitMQ AMQP language bindings for Erlang.

%prep
%setup -q
%patch0
%patch1
%define _rabbit_server_ocf `basename %{SOURCE4}`
cp %{SOURCE4} %{_rabbit_server_ocf}
#patch10 -p1

%build
make all VERSION=%{version}
# %{?_smp_mflags}

%install
make install \
  TARGET_DIR=%{buildroot}%{_rabbit_erllibdir} \
  SBIN_DIR=%{buildroot}%{_rabbit_libdir}/bin \
  MAN_DIR=%{buildroot}%{_mandir} \
  DOC_INSTALL_DIR=%{buildroot}/%{_docdir} \
  VERSION=%{version}

mkdir -p %{buildroot}%{_sbindir}
%if 0%{?have_systemd}
install -p -D -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/%{name}.service
ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
# Install init scripts
install -p -D -m 0755 %{SOURCE1} %{buildroot}%{_initddir}/rabbitmq-server
ln -sf %{_initddir}/rabbitmq-server %{buildroot}%{_sbindir}/rcrabbitmq-server
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates/
install -p -D -m 644 %{SOURCE5} %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.rabbitmq-server
%endif

# Install wrapper scripts
%define _rabbit_wrapper %{_builddir}/`basename %{SOURCE2}`
cp %{SOURCE2} %{_rabbit_wrapper}
sed -i 's|@SU_RABBITMQ_SH_C@|su rabbitmq -s /bin/sh -c|' %{_rabbit_wrapper}
sed -i 's|/usr/lib/|%{_libdir}/|' %{_rabbit_wrapper}
install -p -D -m 0755 %{_rabbit_wrapper} %{buildroot}%{_sbindir}/rabbitmqctl
install -p -D -m 0755 %{_rabbit_wrapper} %{buildroot}%{_sbindir}/rabbitmq-server
install -p -D -m 0755 %{_rabbit_wrapper} %{buildroot}%{_sbindir}/rabbitmq-plugins
install -p -D -m 0755 %{_rabbit_server_ocf} %{buildroot}%{_exec_prefix}/lib/ocf/resource.d/rabbitmq/rabbitmq-server

# install config files
install -p -D -m 0644 docs/rabbitmq.config.example %{buildroot}/%{_sysconfdir}/rabbitmq/rabbitmq.config

# Copy all necessary lib files etc.
install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/rabbitmq-server

# Install Erlang client
mkdir -p %{buildroot}%{_libdir}/erlang/lib
for i in amqp_client rabbit_common ; do
   unzip %{buildroot}%{_rabbit_erllibdir}/plugins/$i*.ez -d %{buildroot}%{_libdir}/erlang/lib
done

# Create other necessary directories for RabbitMQ server
mkdir -p %{buildroot}%{_sysconfdir}/rabbitmq
mkdir -p %{buildroot}%{_localstatedir}/lib/rabbitmq/mnesia
mkdir -p %{buildroot}%{_localstatedir}/log/rabbitmq

# tmpfiles.d for systemd
%if 0%{?have_systemd}
mkdir -p %{buildroot}%/usr/lib/tmpfiles.d
install -p -D -m 0644 %{SOURCE7} %{buildroot}/usr/lib/tmpfiles.d/rabbitmq-server.conf
%endif

# Build the list of files
rm -f %{_builddir}/filelist.%{name}.rpm
echo '%defattr(-,root,root, -)' >> %{_builddir}/filelist.%{name}.rpm
(cd %{buildroot}; \
    find . -type f ! -regex '\.%{_sysconfdir}.*' \
        ! -regex '\.\(%{_rabbit_erllibdir}\|%{_rabbit_libdir}\).*' \
        | sed -e 's/^\.//' >> %{_builddir}/filelist.%{name}.rpm)

# Create hardlinks for duplicate files
%fdupes %{buildroot}/usr/share

%pre
getent group rabbitmq >/dev/null || groupadd -r rabbitmq
getent passwd rabbitmq >/dev/null || useradd -r -g rabbitmq \
  -d %{_localstatedir}/lib/rabbitmq \
  -s /sbin/nologin \
  -c "user for RabbitMQ messaging server" rabbitmq
%if 0%{?have_systemd}
%service_add_pre %{name}.service
%endif

%post
%if 0%{?have_systemd}
%service_add_post %{name}.service
systemd-tmpfiles --create --clean /usr/lib/tmpfiles.d/rabbitmq-server.conf
%else
%fillup_and_insserv rabbitmq-server
%endif

%preun
%if 0%{?have_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal rabbitmq-server
%endif

%postun
%if 0%{?have_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update rabbitmq-server
%insserv_cleanup
%endif

%files -f ../filelist.%{name}.rpm
%defattr(-,root,root,-)
%attr(0750, rabbitmq, rabbitmq) %dir %{_localstatedir}/lib/rabbitmq
%attr(0750, rabbitmq, rabbitmq) %dir %{_localstatedir}/log/rabbitmq
%dir %{_sysconfdir}/rabbitmq
%dir %{_rabbit_libdir}
%{_rabbit_libdir}/bin
%dir %{_rabbit_libdir}/lib
%{_rabbit_erllibdir}
%if 0%{?have_systemd}
%{_unitdir}/%{name}.service
/usr/lib/tmpfiles.d/rabbitmq-server.conf
%else
%{_initddir}/rabbitmq-server
%endif
%{_sbindir}/rcrabbitmq-server
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/rabbitmq
%config(noreplace) %{_sysconfdir}/logrotate.d/rabbitmq-server
%config(noreplace) %{_sysconfdir}/rabbitmq/rabbitmq.config
%doc LICENSE* README
%dir %{_rabbit_erllibdir}/plugins
%exclude %{_rabbit_erllibdir}/plugins/*
%exclude %{_libdir}/erlang/lib/amqp_client*/*
%exclude %{_libdir}/erlang/lib/rabbit_common*/*

%files plugins
%defattr(-,root,root)
%{_rabbit_erllibdir}/plugins/

%files -n erlang-rabbitmq-client
%defattr(-,root,root)
%{_libdir}/erlang/lib/amqp_client*/
%{_libdir}/erlang/lib/rabbit_common*/

%changelog
* Tue Jan 17 2017 chris@intrbiz.com
- Update to 3.5.8
  Fixes logging issues on erlang 17+
  Fixes MQTT password authentication error (CVE-2016-9877) (boo#1017642)
* Thu Apr 14 2016 aplanas@suse.com
  Fix bsc#973999
- rabbitmq-server.service: increase NOFILE limit per documentation
- rabbitqm-server.ocf: add OCF_RESKEY_limit_nofile parameter
  default as 65535_
* Mon Sep 28 2015 dmueller@suse.com
- rabbitmqctl: clear CMDLINE before appending
* Thu Sep 24 2015 dmueller@suse.com
- update to 3.5.4:
  Runtime I/O thread pool size is now 64 instead of 30 by default.
  This reduces time spent waiting for file I/O operations to complete
  on machines with 8 or more cores.
  * https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_5_4
* Wed Jun 24 2015 dmueller@suse.com
- rabbitmq-server.service: switch to type=Notify in order to
  avoid cookie creation race
* Tue Jun 23 2015 tbechtold@suse.com
- update to 3.5.3:
  3.5.2 and 3.5.3 are bugfix releases. See:
  * https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_5_2
  * https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_5_3
* Sun Apr 12 2015 mrueckert@suse.de
- update to 3.5.1
  This release adds support for priority queues which were available
  as a plugin before. Performance is improved; in particular messages
  smaller than configurable size are embedded in the queue index to
  reduce I/O and memory consumption. Stability of clustering and
  autoheal partition handling is improved as well. A new
  pause_if_all_down partition handling mode is added. The management
  web UI now shows many more I/O statistics.
  This release also corrects a number of defects in the broker and
  plugins, as well as introducing many smaller new features and
  improvements.
  * see https://www.rabbitmq.com/release-notes/README-3.5.1.txt
  * see https://www.rabbitmq.com/release-notes/README-3.5.0.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.4.txt
- instead of patching the ocf provider after copying: patch it
  right away and drop the ocf-fixes.patch.
- refresh no-nmap.patch to apply cleanly again
- create rcrabbitmq-server for the systemd case
* Wed Jan 21 2015 dmueller@suse.com
- update to 3.4.3:
  * prevent XSS attack in table key names (since 2.4.0)
    (CVE-2015-0862)
  * prevent XSS attack in policy names (since 3.4.0)
    (CVE-2015-0862)
  * prevent XSS attack in client details in the connections list
    (CVE-2015-0862)
  * prevent XSS attack in user names in the vhosts list or the vhost names
    in the user list (since 2.4.0)
    (CVE-2015-0862)
  * prevent XSS attack in the cluster name (since 3.3.0)
    (CVE-2015-0862)
  * prevent /api/* from returning text/html error messages which could
    act as an XSS vector (since 2.1.0)
  * fix response-splitting vulnerability in /api/downloads (since 2.1.0)
  * do not trust X-Forwarded-For header when enforcing 'loopback_users'
    (CVE-2014-9494)
  * disable SSLv3 by default to prevent the POODLE attack
  * see https://www.rabbitmq.com/release-notes/README-3.4.3.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.2.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.1.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.0.txt
* Mon Nov 24 2014 dmueller@suse.com
- ignore stop errors in %%preun
* Sun Sep 14 2014 tbechtold@suse.com
- update to 3.3.5:
  * Bug fixes, see
  - https://www.rabbitmq.com/release-notes/README-3.3.2.txt
  - https://www.rabbitmq.com/release-notes/README-3.3.3.txt
  - https://www.rabbitmq.com/release-notes/README-3.3.4.txt
  - https://www.rabbitmq.com/release-notes/README-3.3.5.txt
* Sun Jul 20 2014 p.drouand@gmail.com
- The package doesn't provide any sysvinit script or sysconfig file;
  remove dependencies to fillup or insserv if the package build with
  systemd support
* Mon May  5 2014 dmueller@suse.com
- update to 3.3.1:
  * Bug fixes
  * Security fixes to MQTT and shovel
  * see http://www.rabbitmq.com/release-notes/README-3.3.1.txt
* Wed Apr 30 2014 dmueller@suse.com
- do not install init script on systemd distros
* Thu Apr 10 2014 matwey.kornilov@gmail.com
- require epmd.socket in .service in order not to start earlier
  than epmd.socket
* Fri Apr  4 2014 dmueller@suse.com
- update to 3.3.0:
  * long list of security, bugfixes and enhancements
  * see http://www.rabbitmq.com/release-notes/README-3.3.0.txt
* Wed Apr  2 2014 vuntz@suse.com
- Add ocf-fixes.patch to fix issues in the OCF file:
  - use the wrapper function to call rabbitmqctl for stop, so that
    we interpret correctly the exit code.
  - accept 1 as valid exit code from "rabbitmqctl status", instead
    of totally breaking when we get it.
- We use a patch as the OCF file comes from upstream, so it's
  better to keep the changes isolated.
* Thu Mar 27 2014 dmueller@suse.com
- update to 3.2.4:
  * Several bug fixes, no detailed changelog available
- remove fix-syntax-error-in-example-conf.patch: merged upstream
* Fri Jan 24 2014 dmueller@suse.com
- update to 3.2.3:
  * This release fixes a number of bugs in the broker and federation plugin
  * Improvements to the LDAP and shovel plugins are also included
* Thu Jan 23 2014 dmueller@suse.com
- install a config file by default
  add fix-syntax-error-in-example-conf.patch
* Tue Jan 21 2014 dmueller@suse.com
- update to 3.2.2:
  * federated queues and features enhanced policies for aspects of the broker
  * This release fixes a number of bugs in the broker and plugins
* Tue Jan  7 2014 matwey.kornilov@gmail.com
- add Provides: erlang-gen_server2 to erlang-rabbitmq_client
  (many people want gen_server2, which is a part of rabbitmq)
* Fri Sep 20 2013 dmueller@suse.com
- fix syntax error in wrapper script
* Fri Sep 13 2013 dmueller@suse.com
- update to 3.1.5:
  * various security fixes and bugfixes
  * see http://www.rabbitmq.com/release-notes/README-3.1.5.txt
  * see http://www.rabbitmq.com/release-notes/README-3.1.4.txt
* Wed Jul  3 2013 dmueller@suse.com
- update to 3.1.3:
  * Eager synchronisation of mirror queue slaves
  * Automatic cluster partition healing
  * Charts in the management plugin
  * Queue length limits
  * Bug fixes
  * Fixes a security bug in federation
* Wed Apr 24 2013 tpaszkowski@novell.com
- fix rabbitmq-server startup on systemd enabled systems (create
  /var/run/rabbitmq-server directory using systemd-tmpfiles mechanism)
* Wed Apr  3 2013 dmueller@suse.com
- Change init script to properly daemonize (patch by jdsn) (bnc#807540)
* Sun Mar 17 2013 matwey.kornilov@gmail.com
- Added systemd .service file
* Wed Mar 13 2013 berendt@b1-systems.de
- updated to version 3.0.4
  * 3.0.4: This release fixes a bug in the federation plugin
    where upstream credentials were leaked in the
    x-received-from header. This bug had been in the federation
    plugin since RabbitMQ 3.0.0. There are no other changes
    from RabbitMQ 3.0.3.
  * 3.0.3: This release fixes a small number of bugs in 3.0.2
    and earlier versions.
  * 3.0.2: This release fixes a number of bugs in 3.0.1 and
    earlier versions.
  * 3.0.1: This release fixes a number of bugs in 3.0.0 and
    earlier versions.
  * 3.0.0: This release introduces dynamic, policy-based control
    of mirroring and federation, improves the user friendliness
    of clustering, adds support for per-message TTL, introduces
    plugins for web-STOMP and MQTT, and adds many smaller new
    features and bug fixes.
- rebased no-remove-common.patch
* Fri Dec 14 2012 rhafer@suse.com
- sysconfig file cleanup
  * remove unused Variables
  * removed variables which can also be set in rabbitmq-env.conf
    to avoid sysconfig settings overriding settings from the env
    file (bnc#771151)
- Use rc.status functions in init script for prettier startup
- Remove "set -e" from init script (bnc#768175)
- Include OCF RA for use with Pacemaker
- Updated script-wrapper to the latest upstream code
* Fri Dec 14 2012 saschpe@suse.de
- Don't use download_files service, or at least only in mode="localonly"
  or mode="disabled". But why using it at all, it makes no sense.
* Mon Dec 10 2012 rhafer@suse.com
- Update to 2.8.7 changes since:
  * 2.8.6: This release fixes a number of bugs in the broker,
    Erlang client and STOMP and management plugins.
  * 2.8.5: This release fixes a number of bugs, including one
    introduced in 2.8.5 that could cause an error during shutdown
    of mirrored queues.
  * 2.8.4: This is primarily a bugfix release, with several
    improvements to HA queues.
* Fri Aug 17 2012 mbarringer@suse.com
- Fixing logrotate errors (bnc#775867)
* Mon Jul 16 2012 matwey.kornilov@gmail.com
- Updated to 2.8.4
* Wed May  9 2012 matwey.kornilov@gmail.com
- Updated to 2.8.2
* Fri Apr 13 2012 jblunck@opensuse.org
- Require python >= 2.6 for json
- Add _initddir define for SLE11 build
* Tue Feb 14 2012 saschpe@suse.de
- Fixed doubled preamble entries
* Thu Feb  2 2012 bwiedemann@suse.com
- fix /var/run/rabbitmq ownership
* Tue Jan 10 2012 prusnak@opensuse.org
- updated to 2.7.1
- don't use nmap during the build (no-nmap.patch)
- don't use /var/lock/subsys in initscript
- create /var/run/rabbitmq in initscript
- import changes from Fedora package
* Sun Oct  4 2009 dpw@lshift.net
- New upstream release
* Tue Jun 16 2009 matthias@lshift.net
- New upstream release
* Mon May 18 2009 matthias@lshift.net
- Maintenance release for the 1.5.x series
* Sun Apr  5 2009 matthias@lshift.net
- Maintenance release for the 1.5.x series
* Mon Feb 23 2009 tonyg@lshift.net
- Maintenance release for the 1.5.x series
* Sun Feb 22 2009 tonyg@lshift.net
- Maintenance release for the 1.5.x series
* Sun Jan 18 2009 0x6e6562@gmail.com
- Maintenance release for the 1.5.x series
* Tue Dec 16 2008 matthias@lshift.net
- New upstream release
* Wed Jul 23 2008 tonyg@lshift.net
- New upstream release
* Sun Mar  2 2008 adrian@lshift.net
- New upstream release
* Tue Sep 25 2007 simon@lshift.net
- New upstream release
* Tue Aug 28 2007 simon@lshift.net
- New upstream release
* Sun Jul 29 2007 simon@lshift.net
- New upstream release
* Mon Jun 11 2007 hubert@lshift.net
- Building from source tarball, added starting script, stopping
* Sun May 20 2007 hubert@lshift.net
- Initial build of server library of RabbitMQ package
